==> banking-branch_14.8.0.0.0-Plus1.zip: banking-branch_14.8.0.0.0-Plus1_20250419/content/banking-branch/14.8.0.0.0/gsugu/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-572684A2-A115-406A-AAF5-3A3F76E53B8E"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Getting Started",
                    "href":"getting-started.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Accessing Application",
                            "href":"accessing-application.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.1.1 </span> Signing In",
                                    "href":"signing1.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.2 </span> Signing Out",
                                    "href":"signing.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Overview of Application Environment",
                    "href":"overview-application-environment.html"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Overview of Screen Environment",
                    "href":"overview-screen-environment.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> About Dashboard",
                            "href":"dashboard.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.2 </span> About Teller Transaction Screen",
                            "href":"teller-transaction-screen.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.3 </span> About Servicing Transaction Screen",
                            "href":"servicing-transaction-screen.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.4 </span> About Summary Screen",
                            "href":"summary-screen.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.5 </span> About Maintenance Screen",
                            "href":"maintenance-screen.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.6 </span> About Other Screens",
                            "href":"other-screens.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> How Tos",
                    "href":"how-tos.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">4.1 </span> Perform Customer Financial Transactions, Customer Servicing Transactions, and Branch Operations",
                            "href":"perform-customer-financial-transactions-customer-servicing-transactions-and-branch-operations.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.2 </span> Perform Maintenance",
                            "href":"perform-maintenance.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">4.2.1 </span> Common Tasks in Maintenance Screens",
                                    "href":"common-tasks-maintenance-screens.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">4.3 </span> Configure Dashboard",
                            "href":"configure-dashboard.html"
                        }
                    ]
                },
                {
                    "title":"Index",
                    "href":"book-index.html"
                }
            ]
        }
    ]
});

==> banking-branch_14.8.1.0.0-Plus1.zip: banking-branch_14.8.1.0.0-Plus1_20251105/content/banking-branch/14.8.1.0.0/gsugu/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-572684A2-A115-406A-AAF5-3A3F76E53B8E"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Getting Started",
                    "href":"getting-started.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Accessing Application",
                            "href":"accessing-application.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.1.1 </span> Signing In",
                                    "href":"signing.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.1.2 </span> Signing Out",
                                    "href":"signing-out.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Overview of Application Environment",
                    "href":"overview-application-environment.html"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Overview of Screen Environment",
                    "href":"overview-screen-environment.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> About Dashboard",
                            "href":"dashboard1.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.2 </span> About Teller Transaction Screen",
                            "href":"teller-transaction-screen1.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.3 </span> About Servicing Transaction Screen",
                            "href":"servicing-transaction-screen.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.4 </span> About Summary Screen",
                            "href":"summary-screen1.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.5 </span> About Maintenance Screen",
                            "href":"maintenance-screen.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.6 </span> About Other Screens",
                            "href":"other-screens1.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> How Tos",
                    "href":"how-tos.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">4.1 </span> Perform Customer Financial Transactions, Customer Servicing Transactions, and Branch Operations",
                            "href":"perform-customer-financial-transactions-customer-servicing-transactions-branch-operations.html"
                        },
                        {
                            "title":"<span class=\"secnum\">4.2 </span> Perform Maintenance",
                            "href":"perform-maintenance.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">4.2.1 </span> Common Tasks in Maintenance Screens",
                                    "href":"common-tasks-maintenance-screens.html"
                                }
                            ]
                        },
                        {
                            "title":"<span class=\"secnum\">4.3 </span> Configure Dashboard",
                            "href":"configure-dashboard.html"
                        }
                    ]
                },
                {
                    "title":"Index",
                    "href":"book-index.html"
                }
            ]
        }
    ]
});
